@@ -1,19 +1,18 @@
 # Test function plotbetas #
 
-# Test that plotbetas produces a ggplot objects #
-# Test that plotbetas produces new plots for quad and cub #
 test_that("plotbetas produces a graph", {
   
   data(Mass, envir = environment())
   data(MassClimate, envir = environment())
   
-  testdata <- climatewin(xvar = list(MassClimate$Temp), cdate = MassClimate$Date, bdate = Mass$Date, 
-                         baseline = lm(Mass ~ 1, data = Mass), furthest = 3, closest = 2, 
-                         type = "variable", stat = "max", func = "lin", cmissing = FALSE)
+  testdata <- slidingwin(xvar = list(MassClimate$Temp), cdate = MassClimate$Date, bdate = Mass$Date, 
+                         baseline = lm(Mass ~ 1, data = Mass), range = c(3, 2), 
+                         type = "relative", stat = "max", func = "lin", cmissing = FALSE)
   
   testenv <- environment()
   test    <- plotbetas(dataset = testdata[[1]]$Dataset)
   
+  # Test that a ggplot object is produced
   expect_true(attr(test, "class")[1] == "gg")
  
   testdata[[1]]$Dataset$ModelBetaQ <- testdata[[1]]$Dataset$ModelBeta
@@ -21,6 +20,7 @@ test_that("plotbetas produces a graph", {
   
   test <- plotbetas(dataset = testdata[[1]]$Dataset, plotall = TRUE, plotallenv = testenv)
   
+  # Test that a second graph is produced when func = quad
   expect_true(exists("beta2", envir = testenv))
   
   testdata[[1]]$Dataset$ModelBetaC <- testdata[[1]]$Dataset$ModelBeta
@@ -28,7 +28,10 @@ test_that("plotbetas produces a graph", {
   
   test <- plotbetas(dataset = testdata[[1]]$Dataset, plotall = TRUE, plotallenv = testenv)
   
+  # Test that a second graph is produced when func = cub
   expect_true(exists("beta2", envir = testenv))
+  
+  # Test that a third graph is produced when func = cub
   expect_true(exists("beta3", envir = testenv))
   
 })
\ No newline at end of file
